import * as argon2 from "argon2";
import { IsBoolean, IsOptional, IsString } from 'class-validator';
import * as uuid from 'uuid';
import { StatsClient } from '../entities/StatsClient';

/**
 * This classed is used to create a new StatsClient entity from a json body (post request).
 */
export class CreateStatsClient {
    /**
     * The new client's description.
     */
    @IsString()
    @IsOptional()
    description?: string;

    /**
     * Is the new client enabled.
     */
    @IsBoolean()
    @IsOptional()
    enabled?: boolean;

    /**
     * Converts this to a StatsClient entity.
     */
    public async toStatsClient(): Promise<StatsClient> {
        let newClient: StatsClient = new StatsClient();

        newClient.description = this.description;
        newClient.key = await argon2.hash(uuid.v4());
        if (this.enabled === undefined || this.enabled === null) { newClient.enabled = true; }
        else { newClient.enabled = this.enabled }

        return newClient;
    }
}